Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2266)

Unified Diff: chrome/common/render_messages_params.h

Issue 3834003: On Windows, create a new TransportDIB::Handle struct which includes the file (Closed) Base URL: http://src.chromium.org/git/chromium.git
Patch Set: Rebase Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/render_messages_params.h
diff --git a/chrome/common/render_messages_params.h b/chrome/common/render_messages_params.h
index 2eeff7075862e0aab4c24df2351b736ca06d5dea..211de1aee0d9c6ebf7872e4054df6e43198e8137 100644
--- a/chrome/common/render_messages_params.h
+++ b/chrome/common/render_messages_params.h
@@ -321,9 +321,12 @@ struct ViewHostMsg_UpdateRect_Params {
ViewHostMsg_UpdateRect_Params();
~ViewHostMsg_UpdateRect_Params();
- // The bitmap to be painted into the view at the locations specified by
- // update_rects.
- TransportDIB::Id bitmap;
+ // The ID of the bitmap to be painted into the view at the locations specified
+ // by update_rects.
+ TransportDIB::Id dib_id;
+
+ // The handle to the bitmap, in case it needs to be mapped on the browser.
+ TransportDIB::Handle dib_handle;
// The position and size of the bitmap.
gfx::Rect bitmap_rect;

Powered by Google App Engine
This is Rietveld 408576698